function championnat_pref()
% Variante de la fonction "championnat" utilisant l'échantillonnage
% préférentiel pour évaluer la probabilité de victoire de l'équipe la moins
% forte. Je ne commente que les différences

tic;
N = 70000;
nequipes = 16;
% Cette fois-ci c'est l'équipe #16 qui nous intéresse.
Nancy = 16;

% bilan est toujours le nombre de simulations où l'équipe qui nous
% intéresse a été classée championne, mais cette fois-ci pondéré par la
% densité de la vraie loi par rapport à la loi d'échantillonnage.
bilan = 0;
% Pour donner un intervalle de confiance et évaluer l'efficacité, il va
% aussi nous falloir connaitre la somme des carrés des quantités simulées.
sommecarres = 0;

for i = 0 : N-1
    % Puisque nous n'échantillonnons pas sous la véritable loi, il nous
    % faut aussi calculer la densité relative de la véritable loi. Celle-ci
    % va s'obtenir comme un produit de densités partielles indépendantes
    % entre elles, aussi nous l'initialisons à 1.
    densite = 1;
    victoires = zeros(1,nequipes);
    % On commence par simuler les résultats de l'équipe qui nous intéresse.
    % Ceux-ci étant tirés selon la loi uniforme, qui n'est pas la vraie
    % loi, il nous faudra en tenir compte pour la densité.
    for b = 1 : nequipes
        % Il faut penser à ne pas simuler de match de Nancy contre
        % elle-même...
        if b ~= Nancy
            % Notre simulation donne 50 % de probabilité de victoire à
            % Nancy pour chaque match
            if rand < 1/2
                % En cas de victoire...
                victoires(Nancy) = victoires(Nancy) + 1;
                % On modifie la densité pour tenir compte de
                % l'échantillonnage préférentiel.
                densite = densite * 2/(1+(Nancy/b)^(1/2));
            else
                % En cas de défaite...
                victoires(b) = victoires(b) + 1;
                densite = densite * 2/(1+(b/Nancy)^(1/2));
            end
        end
    end
    
    % Maintenant on simule les autres matchs, cette fois-ci directement
    % sous la vraie probabilité
    for a = 1 : nequipes
        for b = a+1 : nequipes
            % N'oublions pas de ne pas refaire les simulations impliquant
            % Nancy...
            if (a ~= Nancy && b ~= Nancy)
            if rand < 1/(1+(b/a)^(1/2))
                victoires(b) = victoires(b) + 1;
            else
                victoires(a) = victoires(a) + 1;
            end
            end
        end
    end
    victoires = victoires + rand(1,nequipes);
    [~,championne] = max(victoires);
        % Maintenant, il va falloir tenir compte de la pondération dans le
        % bilan !
        contribution = (championne == Nancy) * densite;
        bilan = bilan + contribution;
        sommecarres = sommecarres + contribution * contribution;
end

probabilite = bilan / N;
ecarttype = sqrt (sommecarres/N - probabilite*probabilite);
disp ('Probabilité de victoire évaluée pour l''équipe de Nancy :');
disp (probabilite);
disp ('±');
disp (1.96*ecarttype/sqrt(N));

t = toc;
disp ('Durée du calcul en s :')
disp (t);
end