function lapin

% Calcul de la constante c, par la méthode de Newton.
c = -.1+.7i; % On initialise c près de la bonne valeur.
% Rappelons qu'on cherche à annuler le polynôme c³+2c²+c+1.
ancienneerreur = +Inf;
while true
    erreur = c*c*c + 2*c*c + c + 1;
    % On n'est pas sûr que l'erreur va arriver à exactement zéro ; c'est
    % pourquoi il faut prévoir une sortie de la boucle dès que l'erreur ne
    % décroit plus.
    if (abs(erreur) >= ancienneerreur)
        break;
    end
    derivee = 3*c*c + 4*c + 1;
    c = c - erreur / derivee;
    ancienneerreur = abs(erreur);
end

N = 1000000;
total = 0; % Total des résultats des simulations.

for i = 1:N
    % On tire z uniformément sur le carré.
    z = (-2+rand*4) + (-2+rand*4)*1i;
    % On lance la boucle des itérations de z jusqu'à pouvoir déterminer si
    % c'est un point du lapin ou non.
    while true
        if (abs(z) > 2.) % Le z initial n'appartenait pas au lapin.
            contribution = 0;
            break;
        elseif (abs(z) < .25) % Le z initial appartenait au lapin.
            contribution = 16;
            break;
        else
            z = z*z + c;
        end
    end
    total = total + contribution;
end

moyenne = total / N;
disp('Aire estimée du lapin de Douady :');
disp(moyenne);
end
