function loterie_cond

% La fonction "loterie_cond" effectue le même travail que "loterie_IC",
% mais en utilisant une technique de conditonnement. Je ne commente que les
% différences.

N = 700000;
Nnumeros = 36;
Ntirages = 12;
total = 0;
totalcarres = 0;

for i = 0 : N-1
    
    % Cette fois-ci on ne va réellement tirer que onze numéros.
    numerostires = zeros(1,Ntirages-1);
    boules = 1 : Nnumeros;
    nombredeboules = Nnumeros;
    nombretirees = 0;
    for j = 1 : Ntirages-1
        laboule = randi(nombredeboules);
        numerostires(nombretirees+1) = boules(laboule);
        boules (laboule) = boules (nombredeboules);
        nombredeboules = nombredeboules - 1;
        nombretirees = nombretirees + 1;
    end
    % Pour des raisons techniques, il va nous être pratique ici de
    % maintenir la liste des numéros sortis *parmi ceux que notre joueuse a
    % coché*. Nous codons cela sous la forme d'un tableau de 12 variables
    % booléennes valant ‘true’ en position #i si le numéro coché i est
    % sorti et ‘false’ sinon. Ce tableau est appelé "cochesetsortis".
    cochesetsortis = false * ones(1,12);
    for j = 1 : Ntirages-1
        if numerostires(j) <= Ntirages
            cochesetsortis(numerostires(j)) = true;
        end
    end
    
    % À l'issue de ces 11 tirages, nous obtenons un score partiel ;
    % maintenant, ce qui va nous intéresser est l'espérance du gain
    % conditionnellement à ce score partiel.
    scorepartiel = cochesetsortis * (1:12)';
    % Nous appelons "contribution" l'espérance conditionnelle. Nous
    % obtenons celle-ci simplement en comptant séparément les nouveaux cas
    % possibles.
    contribution = 0;
    for j = 1 : Ntirages
        if ~cochesetsortis(j)
            score = scorepartiel + j;
            if score >= 39
            contribution = contribution + floor(exp((score-39)/8));
            end
        end
    end
    % Chaque élément précédemment compté avait en fait une probabilité de 1
    % sur 25 ; il faut donc diviser "contribution" par 25 pour avoir la
    % véritable contribution.
    contribution = contribution / 25;
    
    total = total + contribution;
    totalcarres = totalcarres + contribution*contribution;
end

moyenne = total / N;
ecarttype = sqrt(totalcarres / N - moyenne * moyenne);
disp ('Intervalle de confiance pour le gain moyen :');
disp ([num2str(moyenne),' ± ',num2str(2.81*ecarttype/sqrt(N))]);

end