% La fonction "mathfi_anti" améliore "mathfi_naif" en y implémentant la
% méthode des variables antithétiques. N est le nombre de simulations
% demandées. Je ne commente que les différences par rapport à
% "mathfi_naif".
function mathfi_anti(N)
% Pour commencer, comme les simulations vont en fait être effectuées par
% deux, le “vrai” N doit être divisé par deux par rapport à celui indiqué
% en paramètre.
N = ceil(N/2);
T = 60;
somme = 0;
somme2 = 0;
for i = 1:N
    % Il y a maintenant deux trajectoires à simuler, que nous appelons
    % respectivement "X" et "Xanti". Le tirage des gaussiennes qui servent
    % à simuler "Xanti" est inversé par rapport à celui de "X". (Noter
    % qu'ici la correspondance entre la trajectoire de X et celle de X anti
    % est triviale, mais la méthode de retournement des gaussiennes par
    % laquelle je suis passé a le mérite d'être plus générale).
    X = zeros(1,T+1);
    Xanti = zeros(1,T+1);
    Xt = 0;
    Xantit = 0;
    for t = 1:T
        r = randn(1);
        Xt = Xt + r;
        Xantit = Xantit - r;
        X(t+1) = Xt;
        Xanti(t+1) = Xantit;
    end
    % On évalue "Xmax" et "Xantimax" qui est la valeur de Xmax pour Xanti.
    Xmax = max(X);
    Xantimax = max(Xanti);
    % La valeur dont nous allons calculer l'espérance par Monte-Carlo est
    % celle de Xmax + Xantimax ; c'est par rapport à elle que nous
    % maintenons "somme" et "somme2".
    valeur = Xmax + Xantimax;
    somme = somme + valeur;
    somme2 = somme2 + valeur*valeur;
end
% "mvaleur", "ectype" et "errvaleur" sont les quantités de l'estimation de
% Monte-Carlo pour "valeur".
mvaleur = somme / N;
ectype = sqrt (somme2/N - mvaleur*mvaleur);
errvaleur = 1.96 * ectype / sqrt(N);
% L'estimation qui nous intéresse est celle de l'espérance de X_*, qui est
% la moitié de l'espérance de "valeur" : pour obtenir son estimation et son
% intervalle de confiance, il faut tout diviser par 2.
m = mvaleur / 2;
erreur = errvaleur / 2;
fprintf('Estimation de E(X_*) : %.5f ± %.5f\n', m, erreur);
return
end