% "mathfi_ctrl1" utilise la même variable de contrôle que "mathfi_ctrl0",
% mais en version paramétrée. Je ne commente que les différences avec
% "mathfi_ctrl0".
function mathfi_ctrl1(N)
T = 60;
somme = 0;
somme2 = 0;
% Cette fois-ci, il faut aussi maintenir la somme des simulations de Y et
% des Y^2 ("sommeY" et "sommeY2"), ainsi que la somme des produits Xmax * Y
% ("sommeprod").
sommeY = 0;
sommeY2 = 0;
sommeprod = 0;
for i = 1:N
    X = zeros(1,T+1);
    Xt = 0;
    for t = 1:T
        Xt = Xt + randn(1);
        X(t+1) = Xt;
    end
    Xmax = max(X);
    Y = max(X(T+1),0);
    % Pour l'instant on ne sait pas encore quelle va être la valeur dont on
    % calcule l'espérance par Monte-Carlo, donc on maintient à jour toutes
    % les sommes introduites précédemment.
    somme = somme + Xmax;
    somme2 = somme2 + Xmax*Xmax;
    sommeY = sommeY + Y;
    sommeY2 = sommeY2 + Y*Y;
    sommeprod = sommeprod + Xmax*Y;
end
% On évalue la moyenne covariance "covariance" entre Xmax et Y, ainsi que
% la variance "varY" de Y. On en profite aussi pour calculer la variance
% "varXmax" de Xmax, qui nous servira plus loin.
moyenneXmax = somme / N;
moyenneY = sommeY / N;
covariance = sommeprod/N - moyenneXmax * moyenneY;
varY = sommeY2/N - moyenneY*moyenneY;
varXmax = somme2/N - moyenneXmax*moyenneXmax;
% On cherche maintenant le paramètre "lambda" optimal (ou du moins une
% estimation de celui-ci) pour lequel considérer la quantité d'intérêt
% Xmax-lambda*Y. On utilise pour ce faire la formule du cours.
lambda = covariance / varY;
% Maintenant, il s'agit de savoir quelles ont été l'espérance empirique "m"
% et l'écart-type "ectype" de la quantité d'intérêt Xmax-lambda*Y — toute
% l'astuce étant qu'on peut les calculées à partir dans quantités comptées
% dans la boucle de Monte-Carlo. m est l'estimateur de l'espérance de la
% quantité d'intérêt, dont on calcule la marge d'erreur à partir de ectype.
m = moyenneXmax - lambda * moyenneY;
ectype = sqrt (varXmax - 2*lambda*covariance + lambda*lambda*varY);
erreur = 1.96 * ectype / sqrt(N);
% On en déduit l'estimateur pour E(Xmax) = E(valeur) + lambda*E(Y). Comme
% précédemment, l'addition de EY ne modifie pas la marge d'erreur.
EY = sqrt(T / (2*pi));
mXmax = m + lambda*EY;
erreurXmax = erreur;
fprintf('Estimation de E(X_*) : %.5f ± %.5f\n', mXmax, erreurXmax);
return
end