% "mathfi_ctrl3" fonctionne comme "mathfi_ctrl_1", mais en utilisant trois
% variables de contrôle Y_1, Y_2 et Y_3. Nous utilisons le formalisme
% vectoriel de MATLAB pour traiter les trois variables de contrôle
% collectivement. Je ne commente que les différences avec "mathfi_ctrl1".
function mathfi_ctrl3(N)
T = 60;
somme = 0;
somme2 = 0;
% Attention, "sommeY" est maintenant une quantité vectorielle, dont les
% entrées correspondent respectivement aux sommes des Y_1, des Y_2 et des
% Y_3.
sommeY = zeros(1,3);
% Attention, "sommeY2" est maintenant une quantité matricielle :
% "sommeY2(i,j)" contient la somme des produits Y_i * Y_j.
sommeY2 = zeros(3,3);
% Attention, "sommeprod" est maintenant une quantité vectorielle :
% "sommeprod(i)" contient la somme des produits X_* * Y_i.
sommeprod = zeros(1,3);
for i = 1:N
    X = zeros(1,T+1);
    Xt = 0;
    for t = 1:T
        Xt = Xt + randn(1);
        X(t+1) = Xt;
    end
    Xmax = max(X);
    % On calcule cette fois-ci trois variables de contrôle, regroupées dans
    % le vecteur "Y".
    Y = [max(X(21),0), max(X(41),0), max(X(61),0)];
    % Pour l'instant on ne sait pas encore quelle va être la valeur dont on
    % calcule l'espérance par Monte-Carlo, donc on maintient à jour toutes
    % les sommes introduites précédemment.
    somme = somme + Xmax;
    somme2 = somme2 + Xmax*Xmax;
    sommeY = sommeY + Y;
    % Noter le formalisme matriciel pour la mise à jour de sommeY2 (la
    % prime correspond à la transposition).
    sommeY2 = sommeY2 + Y'*Y;
    sommeprod = sommeprod + Xmax*Y;
end
moyenneXmax = somme / N;
moyenneY = sommeY / N;
covariance = sommeprod/N - moyenneXmax * moyenneY;
% Noter le formalisme matriciel pour le calcul de varY.
varY = sommeY2/N - moyenneY'*moyenneY;
varXmax = somme2/N - moyenneXmax*moyenneXmax;
% La paramètre "lambda" est maintenant vectoriel. Sous MATLAB, la commande
% "A / B", quand elle est appliquée à des matrices, calcule le produit A *
% B^{-1} (à l'inverse, "A \ B" calcule B^{-1} * A).
lambda = covariance / varY;
% Notre quantité d'intérêt est maintenant X_* - \lambda_1*Y_1 -
% \lambda_2*Y_2 - lambda_3*Y_3, soit, en formalisme vectoriel, X_* - lambda
% * Y'. À part le formalisme vectoriel auquel il faut faire attention, la
% façon de calculer l'espérance empirique et l'écart-type de X sont les
% mêmes que pour "mathfi_ctrl1".
m = moyenneXmax - lambda * moyenneY';
ectype = sqrt (varXmax - 2*lambda*covariance' + lambda*varY*lambda');
erreur = 1.96 * ectype / sqrt(N);
% "EY" est maintenant vectoriel.
EY = [sqrt(20/(2*pi)), sqrt(40/(2*pi)), sqrt(60/(2*pi))];
% Noter le formalisme vectoriel dans la ligne suivante.
mXmax = m + lambda*EY';
erreurXmax = erreur;
fprintf('Estimation de E(X_*) : %.5f ± %.5f\n', mXmax, erreurXmax);
return
end