% La fonction "mathfi_naif" évalue par la méthode de Monte-Carlo
% l'espérance du maximum d'une marche de 60 pas sur R issue de 0
% d'incréments N(1), sans utiliser de technique de réduction de variance
% particulière. "N" est le nombre de simulations demandées.
function mathfi_naif(N)
% On introduit le raccourci T pour le nombre de pas de temps.
T = 60;
% "somme" et "somme2" contiendront respectivement la somme des résultats
% simulés et la somme de leurs carrés.
somme = 0;
somme2 = 0;
for i = 1:N
    % On simule la trajectoire, resprésentée par le 61-vecteur "X".
    % (Attention, ce que nous appelons X_t dans le polycopié correspond
    % dans le programme à X(t+1), puisque sous MATLAB les indices
    % commencent à 1). Il sera plus rapide de pré-allouer la mémoire pour
    % X, en initialisant le vecteur avec des zéros.
    X = zeros(1,T+1);
    % Boucle pour remplir le vecteur X. "Xt" est la valeur courante de X,
    % et "t" le jour auquel on calcule Xt.
    Xt = 0;
    for t = 1:T
    Xt = Xt + randn(1);
    X(t+1) = Xt;
    end
    % "Xmax" est la valeur du maximum X_* de la trajectoire dans notre simulation.
    Xmax = max(X);
    % On met à jour somme et somme2.
    somme = somme + Xmax;
    somme2 = somme2 + Xmax * Xmax;
end
% "m" est l'estimateur de Monte-Carlo.
m = somme / N;
% "ectype" est l'écart-type (estimé) de X_*.
ectype = sqrt (somme2/N - m*m);
% "erreur" est le rayon de l'intervalle de confiance à 5 %.
erreur = 1.96 * ectype / sqrt(N);
% On affiche le résultat.
fprintf('Estimation de E(X_*) : %.5f ± %.5f\n', m, erreur);
% Le programme s'arrête.
return
end